<!DOCTYPE kpartgui>
<kpartgui name="kasteroids" version="1">
<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
  </Menu>
</MenuBar>
</kpartgui>
