<!DOCTYPE kpartgui>
<kpartgui name="standard_containers" version="5">
<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
    <Action name="new_game"/>
    <Action name="open"/>
    <Action name="save"/>
    <Action name="end_game"/>
    <Separator />
    <Action name="file_network"/>
    <Action name="file_chat"/>
    <Action name="file_debug"/>
    <Separator />
    <Action name="statistics"/>
    <Separator />
    <Action name="hint"/>
    <Separator />
    <Action name="game_exit"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="startplayer" append="save_merge"/>
    <Action name="player1" append="save_merge"/>
    <Action name="player2" append="save_merge"/>
    <Action name="choose_level" append="save_merge"/>
    <Action name="change_names" append="save_merge"/>
    <Action name="show_statusbar" append="show_merge"/>
  </Menu>
</MenuBar>
<StatusBar/>
</kpartgui>
