<!DOCTYPE kpartgui>
<kpartgui name="ktron" version="1">
<MenuBar>
  <Menu name="settings"><text>&amp;Settings</text>
     <Menu name="computerplayer" append="save_merge"><text>&amp;Computer Player</text>
	<Action name="computer_player1"/>
	<Action name="computer_player2"/>
	<Separator/>
	<Action name="skill_beginner"/>
	<Action name="skill_average"/>
	<Action name="skill_expert"/>
     </Menu>
     <Action name="select_velocity" append="save_merge"/>
     <Menu name="appearance" append="save_merge"><text>&amp;Appearance</text>
        <Action name="select_style"/>
	<Action name="color_player1"/>
	<Action name="color_player2"/>
	<Action name="color_background"/>
	<Action name="background_image"/>
     </Menu>
     <Action name="select_size" append="save_merge"/>
     <Action name="configure_other" append="save_merge"/>
  </Menu>
</MenuBar>
</kpartgui>
