<!DOCTYPE kconfig>
<kconfig name="kfouleggs">

<Group name="Options">
  <Entry name="enable animations" vtype="bool" defaultValue="true">
  <text>Enable animations</text>
  </Entry>

  <Entry name="block size" type="ranged" vtype="int"
         defaultValue="21" minValue="21" maxValue="101">
  <text>Block size:</text>
  </Entry>

  <Entry name="fade intensity" type="ranged"
         vtype="double" defaultValue="1" minValue="0" maxValue="1">
  <text>Fade strength:</text>
  </Entry>

  <Entry name="fade color" vtype="QColor" defaultValue="#000000">
  <text>Fade color:</text>
  </Entry>

  <Entry name="show piece shadow" vtype="bool" defaultValue="true">
  <text>Show piece's shadow</text>
  </Entry>

  <Entry name="show next piece" vtype="bool" defaultValue="true">
  <text>Show next piece</text>
  </Entry>

  <Entry name="init level" type="ranged" vtype="int"
         defaultValue="1" minValue="1" maxValue="20">
  <text>Initial level:</text>
  </Entry>

  <Entry name="menubar visible" vtype="bool" defaultValue="true">
  </Entry>
</Group>

<Group name="AI">
  <Entry name="thinking depth" type="ranged" vtype="int"
         defaultValue="2" minValue="1" maxValue="2">
  <text>Thinking depth:</text>
  </Entry>

  <Entry name="occupied lines COEF" type="ranged"
         vtype="double" defaultValue="-2" minValue="-100" maxValue="0">
  <text>Occupied lines:</text>
  </Entry>

  <Entry name="peak-to-peak COEF" type="ranged"
         vtype="double" defaultValue="0" minValue="-100" maxValue="0">
  <text>Peak-to-peak distance:</text>
  </Entry>

  <Entry name="mean height COEF" type="ranged" vtype="double"
         defaultValue="0" minValue="-100" maxValue="0">
  <text>Mean height:</text>
  </Entry>

  <Entry name="spaces COEF" type="ranged" vtype="double"
         defaultValue="0" minValue="-100" maxValue="0">
  <text>Number of spaces:</text>
  <whatsthis>Number of spaces under mean height</whatsthis>
  </Entry>

  <Entry name="removed eggs COEF" type="ranged" vtype="double"
         defaultValue="20" minValue="0" maxValue="100">
  <text>Number of removed eggs:</text>
  </Entry>

  <Entry name="nb puyos COEF" type="ranged"
         vtype="double" defaultValue="50" minValue="0" maxValue="100">
  <text>Number of puyos:</text>
  </Entry>
  <Entry name="nb puyos TRIG" type="ranged"
         vtype="int" defaultValue="0" minValue="0" maxValue="10">
  </Entry>

  <Entry name="nb chained COEF" type="ranged"
         vtype="double" defaultValue="80" minValue="0" maxValue="100">
  <text>Number of chained puyos:</text>
  </Entry>
  <Entry name="nb chained TRIG" type="ranged"
         vtype="int" defaultValue="0" minValue="0" maxValue="10">
  </Entry>
</Group>

</kconfig>
