<!DOCTYPE kpartgui>
<kpartgui name="kpovmodeler" version="4">
<MenuBar>
   <Menu name="game"><text>&amp;Game</text>
      <Action name="new_game" append="new_merge"/>
      <Action name="new_round" append="new_merge"/>
      <Action name="pause" append="misc_merge"/>
   </Menu>
   <Menu name="settings"><text>&amp;Settings</text>
      <Action name="options_player_keys" append="save_merge"/>
      <Action name="options_game" append="save_merge"/>
      <Action name="options_handicap" append="save_merge"/>
      <Action name="options_graphics" append="save_merge"/>
      <Action name="options_ai" append="save_merge"/>
   </Menu>
</MenuBar>

<Toolbar name="mainToolBar"><text>Main Toolbar</text>
   <Action name="new_game"/>
   <Action name="new_round"/>
   <Action name="pause"/>
</Toolbar>
</kpartgui>
