[about]
file=aboute.png
rtti=32
x=150.0
y=50.0
z=0.0

[arrow]
file=arrow%d.png
mask=arrow_mask.png
number=3
offset=19,5
rtti=32
z=9.0

[board]
file=board.png
rtti=32
x=15.0
y=40.0
z=0.0

# more then max(z piece)
[empty]
file=empty2.png
mask=empty2_mask.png
offset=19,12
rtti=32
z=60.0

# Less then z piece
[empty2]
file=empty2.png
offset=19,12
rtti=32
z=5.0

[game]
scorewidget=390,25
spread_x=8
spread_y=8
statuswidget=350,250

[gameover]
desty=140
file=game_over.png
mask=game_over_mask.png
offset=0,0
rtti=32
speed=2.0
x=25.0
y=20.0
z=150.0

[hint]
file=hint.png
mask=piece_mask.png
offset=19,20
rtti=32
z=100.0

[intro1]
color=255,255,0
# Family, pointsize, pixelsize,stylehint,weight,italic,
# ...    undeline,strikeout,fixedpitch,rawmode
# If you want pixelsize. Otherwise just OMIT the pixelsize
# argument
font=Helvetica,-1,25,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=230.0
y=70.0
z=150.0

[intro2]
color=255,255,0
font=Helvetica,-1,20,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=275.0
y=115.0
z=150.0

[intro3]
color=255,255,0
font=Helvetica,-1,25,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=245.0
y=160.0
z=150.0

# z = z..z+21
[piece]
file=piece%d.png
mask=piece_mask.png
number=2
offset=19,20
rtti=32
speed=4.0
z=10.0

[star]
anim0=0,4,2,8
file=star%d.png
mask=star%d_mask.png
number=5
offset=19,20
rtti=32
z=100.0

[text1]
color=255,255,255
font=Helvetica,-1,18,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=30.0
y=170.0
z=150.0

[text2]
color=255,255,255
font=Helvetica,-1,18,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=100.0
y=170.0
z=150.0

[text3]
color=255,255,255
font=Helvetica,-1,18,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=35.0
y=170.0
z=150.0

[text4]
color=255,255,255
font=Helvetica,-1,18,default,50,0,0,0,0,0
rtti=3
text=Dummy
x=40.0
y=170.0
z=150.0

[win4about]
file=introabout.png
mask=introabout_mask.png
rtti=32
x=170.0
x2=340.0
y=265.0
z=1.0
