<!DOCTYPE kconfig>
<kconfig name="kmines">

<Group name="Options">
  <Entry name="menubar visible" vtype="bool" defaultValue="true">
  </Entry>

  <Entry name="level" key="Level" type="multi" defaultValue="easy">
    <text>Choose &amp;Level</text>
    <Item name="easy"><text>Easy</text></Item>
    <Item name="normal"><text>Normal</text></Item>
    <Item name="expert"><text>Expert</text></Item>
    <Item name="custom"><text>Custom</text></Item>
  </Entry>

  <Entry name="custom width" type="ranged" vtype="int"
         defaultValue="10" minValue="5" maxValue="50">
  <text>Width:</text>
  </Entry>
  <Entry name="custom height" type="ranged" vtype="int"
         defaultValue="10" minValue="5" maxValue="50">
  <text>Height:</text>
  </Entry>
  <Entry name="custom mines" type="ranged" vtype="int"
         defaultValue="20" minValue="1" maxValue="2500">
  <text>No. of mines</text>
  </Entry>

  <Entry name="uncertain mark" key="? mark" vtype="bool" defaultValue="true">
  <text>Enable ? mark</text>
  </Entry>

  <Entry name="keyboard game" vtype="bool" defaultValue="false">
  <text>Enable keyboard</text>
  </Entry>

  <Entry name="pause focus" key="paused if lose focus" vtype="bool"
         defaultValue="true">
  <text>Pause if windows lose focus</text>
  </Entry>

  <Entry name="mouse left" type="multi" defaultValue="reveal">
  <text>Left button:</text>
  <Item name="reveal"><text>Reveal</text></Item>
  <Item name="autoreveal"><text>Autoreveal</text></Item>
  <Item name="toggle flag"><text>Toggle Flag</text></Item>
  <Item name="toggle ? flag"><text>Toggle ? Flag</text></Item>
  </Entry>
  <Entry name="mouse mid" type="multi" defaultValue="autoreveal">
  <text>Middle button:</text>
  <Item name="reveal"><text>Reveal</text></Item>
  <Item name="autoreveal"><text>Autoreveal</text></Item>
  <Item name="toggle flag"><text>Toggle Flag</text></Item>
  <Item name="toggle ? flag"><text>Toggle ? Flag</text></Item>
  </Entry>
  <Entry name="mouse right" type="multi" defaultValue="toggle flag">
  <text>Right button:</text>
  <Item name="reveal"><text>Reveal</text></Item>
  <Item name="autoreveal"><text>Autoreveal</text></Item>
  <Item name="toggle flag"><text>Toggle Flag</text></Item>
  <Item name="toggle ? flag"><text>Toggle ? Flag</text></Item>
  </Entry>

  <Entry name="magic reveal" vtype="bool" defaultValue="false">
  <text>"Magic" reveal</text>
  <whatsthis>Set flags and reveal cases where they are trivial.</whatsthis>
  </Entry>

  <Entry name="case size" type="ranged" vtype="int"
         defaultValue="20" minValue="8" maxValue="100">
  <text>Case size:</text>
  </Entry>

  <Entry name="flag color" vtype="QColor" defaultValue="#FF0000">
  <text>Flag color:</text>
  </Entry>
  <Entry name="explosion color" vtype="QColor" defaultValue="#FF0000">
  <text>Explosion color:</text>
  </Entry>
  <Entry name="error color" vtype="QColor" defaultValue="#FF0000">
  <text>Error color:</text>
  </Entry>

  <Entry name="color #0" vtype="QColor" defaultValue="#0000FF">
  <text>1 mine color:</text>
  </Entry>
  <Entry name="color #1" vtype="QColor" defaultValue="#008800">
  <text>2 mines color:</text>
  </Entry>
  <Entry name="color #2" vtype="QColor" defaultValue="#888800">
  <text>3 mines color:</text>
  </Entry>
  <Entry name="color #3" vtype="QColor" defaultValue="#880088">
  <text>4 mines color:</text>
  </Entry>
  <Entry name="color #4" vtype="QColor" defaultValue="#FF0000">
  <text>5 mines color:</text>
  </Entry>
  <Entry name="color #5" vtype="QColor" defaultValue="#880000">
  <text>6 mines color:</text>
  </Entry>
  <Entry name="color #6" vtype="QColor" defaultValue="#000000">
  <text>7 mines color:</text>
  </Entry>
  <Entry name="color #7" vtype="QColor" defaultValue="#000000">
  <text>8 mines color:</text>
  </Entry>

</Group>

</kconfig>
