<!DOCTYPE kpartgui>
<kpartgui name="ksame" version="6">
<MenuBar>
  <Menu name="game">
	<Action name="game_restart"/>
	<Action name="game_highscore"/>
  </Menu>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
	<Action name="random_board"/>
  </Menu>	
</MenuBar>
</ToolBar>
</kpartgui>
