<!DOCTYPE kpartgui>
<kpartgui name="ksnake" version="4">
<MenuBar>
  <Menu name="game"><text>&amp;Game</text></Menu>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
	<Action name="opt_beginner"/>
	<Action name="opt_intermediate"/>
	<Action name="opt_advanced"/>
	<Action name="opt_expert"/>
	<Separator/>
	<Action name="opt_balls"/>
	<Action name="opt_ballsai"/>
	<Action name="opt_snakes"/>
	<Action name="opt_snakesai"/>
	<Separator/>
	<Action name="opt_select_background"/>
	<Action name="opt_backgrounds" />
	<Separator/>
	<Action name="opt_change_keys"/>
	<Separator/>
	<Action name="opt_startroom"/>
  </Menu>
</MenuBar>
</kpartgui>
