<!DOCTYPE kpartgui>
<kpartgui name="katomic" version="4">
<MenuBar>
	<Menu name="settings" noMerge="1"><text>&amp;Settings</text>
		<Action name="options_configure_keybinding"/>
		<Action name="options_configure"/>
	</Menu>
</MenuBar>
</kpartgui>
