<!DOCTYPE kpartgui>
<kpartgui name="kbackgammon" version="2">
<MenuBar>
  <Menu name="game" noMerge="1"><text>&amp;Game</text>    
    <Action name="game_new"/>
    <Action name="game_load"/>
    <Action name="game_save"/>
    <Separator/>
    <Action name="game_print"/>
    <Separator/>
    <Action name="game_quit"/>
  </Menu>
  <Menu name="move" noMerge="1"><text>&amp;Move</text>
    <Action name="move_engine"/>
    <Separator/>
    <Action name="move_undo"/>
    <Action name="move_redo"/>
    <Separator/>
    <Action name="move_load"/>
    <Separator/>
    <Action name="move_roll"/>
    <Action name="move_done"/>
    <Action name="move_cube"/>
  </Menu>
  <Menu name="command_menu"><text>&amp;Command</text>
  </Menu>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
    <Action name="conf_menubar"/>
    <Action name="conf_toolbar"/>
    <Action name="conf_textbar"/>
    <Action name="conf_statbar"/>
    <Separator/>
    <Action name="conf_save"/>
    <Separator/>
    <Action name="conf_keys"/>
    <Action name="conf_tool"/>
    <Action name="conf_conf"/>
  </Menu>
   <Menu name="help"><text>&amp;Help</text>
    <Action name="help_www"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true"><text>Main Toolbar</text>
  <Action name="game_new"/>
  <Separator/>
  <Action name="move_undo"/>
  <Action name="move_load"/>
  <Action name="move_redo"/>
  <Separator/>
  <Action name="move_roll"/>
  <Action name="move_done"/>
  <Action name="move_cube"/>
  <Separator/>
  <Action name="game_print"/>
  <Separator/>
  <Action name="game_quit"/>
  <Separator/>
  <Action name="whatsthis"/>
  <Action name="help"/>
</ToolBar>

<ToolBar name="cmdToolBar" noMerge="1" fullWidth="true"><text>Command Toolbar</text>
  <Action name="command_label"/>
  <Action name="command_lineedit"/>
</ToolBar>

<StatusBar/>

<Menu name="popup">
  <Action name="conf_menubar"/>
  <Separator/>
  <Action name="move_undo"/>
  <Action name="move_redo"/>
  <Separator/>
  <Action name="move_load"/>
  <Separator/>
  <Action name="move_roll"/>
  <Action name="move_cube"/>
  <Action name="move_done"/>
</Menu>
</kpartgui>
